@@ -4,7 +4,7 @@ Main interface for resource-groups service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_resource_groups import (
         Client,
         ListGroupResourcesPaginator,
@@ -13,10 +13,8 @@ Usage::
         SearchResourcesPaginator,
     )
 
-    session = boto3.Session()
-
-    client: ResourceGroupsClient = boto3.client("resource-groups")
-    session_client: ResourceGroupsClient = session.client("resource-groups")
+    session = Session()
+    client: ResourceGroupsClient = session.client("resource-groups")
 
     list_group_resources_paginator: ListGroupResourcesPaginator = client.get_paginator("list_group_resources")
     list_groups_paginator: ListGroupsPaginator = client.get_paginator("list_groups")
